==> ejc-assistrmat-impl-3.0.0-20220330.032415-26-sources.jar: com/ejianc/business/assist/rmat/bean/CheckDetailEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 验收单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistrmat_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="check_id")
    private Long checkId; // 验收主键ID
    @TableField(value="delivery_id")
    private Long deliveryId; // 发货主键ID
    @TableField(value="delivery_detail_id")
    private Long deliveryDetailId; // 发货明细主键ID
    @TableField(value="order_id")
    private Long orderId; // 订单主键ID
    @TableField(value="order_detail_id")
    private Long orderDetailId; // 订单明细主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="deliver_nums_sum")
    private BigDecimal deliverNumsSum; // 送货数量
    @TableField(value="check_nums_sum")
    private BigDecimal checkNumsSum; // 验收数量
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="rmat_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date rmatDate; // 计租日期
    @TableField(value="unit_id")
    private Long unitId; // 单位id
    @TableField(value="unit_name")
    private String unitName; // 单位名称
    @TableField(value="contract_detail_id")
    private Long contractDetailId; // 合同明细来源主键
    @TableField(value="rent_calculation_type")
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租

    @TableField(value="num_m")
    private BigDecimal numM; // 主数量
    @TableField(value="unit_m_id")
    private Long unitMId; // 主单位
    @TableField(value="unit_m_name")
    private String unitMName; // 主单位名称
    @TableField(value="pass_muster")
    private String passMuster; // 是否符合要求(0-否，1-是)
    @TableField(value="rough_weight")
    private BigDecimal roughWeight; // 毛重
    @TableField(value="tare")
    private BigDecimal tare; // 皮重
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="theoretical_weight")
    private BigDecimal theoreticalWeight; // 理论重量
    @TableField(value="trans_scale")
    private BigDecimal transScale; // 转换系数
    @TableField(value="deviation_rate")
    private BigDecimal deviationRate; // 偏差率
    @TableField(value="measure_nums_sum")
    private BigDecimal measureNumsSum; // 计量数量
    @TableField(value="conversion_unit")
    private String conversionUnit; // 重量转换系数单位
    @TableField(value="trans_scale_second")
    private BigDecimal transScaleSecond; // 第二次转换系数(主单位 - 吨)


    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public String getPassMuster() {
        return passMuster;
    }

    public void setPassMuster(String passMuster) {
        this.passMuster = passMuster;
    }

    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }

    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }

    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public BigDecimal getTheoreticalWeight() {
        return theoreticalWeight;
    }

    public void setTheoreticalWeight(BigDecimal theoreticalWeight) {
        this.theoreticalWeight = theoreticalWeight;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }

    public BigDecimal getMeasureNumsSum() {
        return measureNumsSum;
    }

    public void setMeasureNumsSum(BigDecimal measureNumsSum) {
        this.measureNumsSum = measureNumsSum;
    }

    public String getConversionUnit() {
        return conversionUnit;
    }

    public void setConversionUnit(String conversionUnit) {
        this.conversionUnit = conversionUnit;
    }

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    public void setDeliveryDetailId(Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getOrderDetailId() {
        return orderDetailId;
    }

    public void setOrderDetailId(Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getRmatDate() {
        return rmatDate;
    }

    public void setRmatDate(Date rmatDate) {
        this.rmatDate = rmatDate;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }

    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public BigDecimal getTransScaleSecond() {
        return transScaleSecond;
    }

    public void setTransScaleSecond(BigDecimal transScaleSecond) {
        this.transScaleSecond = transScaleSecond;
    }
}

==> ejc-assistrmat-impl-3.0.0-20220526.074351-116-sources.jar: com/ejianc/business/assist/rmat/bean/CheckDetailEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 验收单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistrmat_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="check_id")
    private Long checkId; // 验收主键ID
    @TableField(value="delivery_id")
    private Long deliveryId; // 发货主键ID
    @TableField(value="delivery_detail_id")
    private Long deliveryDetailId; // 发货明细主键ID
    @TableField(value="order_id")
    private Long orderId; // 订单主键ID
    @TableField(value="order_detail_id")
    private Long orderDetailId; // 订单明细主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="deliver_nums_sum")
    private BigDecimal deliverNumsSum; // 送货数量
    @TableField(value="check_nums_sum")
    private BigDecimal checkNumsSum; // 验收数量
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="rmat_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date rmatDate; // 计租日期
    @TableField(value="unit_id")
    private Long unitId; // 单位id
    @TableField(value="unit_name")
    private String unitName; // 单位名称
    @TableField(value="contract_detail_id")
    private Long contractDetailId; // 合同明细来源主键
    @TableField(value="rent_calculation_type")
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    @TableField(value="contract_nums_sum")
    private BigDecimal contractNumsSum; // 合同数量

    @TableField(value="num_m")
    private BigDecimal numM; // 主数量
    @TableField(value="unit_m_id")
    private Long unitMId; // 主单位
    @TableField(value="unit_m_name")
    private String unitMName; // 主单位名称
    @TableField(value="pass_muster")
    private String passMuster; // 是否符合要求(0-否，1-是)
    @TableField(value="rough_weight")
    private BigDecimal roughWeight; // 毛重
    @TableField(value="tare")
    private BigDecimal tare; // 皮重
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="theoretical_weight")
    private BigDecimal theoreticalWeight; // 理论重量
    @TableField(value="trans_scale")
    private BigDecimal transScale; // 转换系数
    @TableField(value="deviation_rate")
    private BigDecimal deviationRate; // 偏差率
    @TableField(value="measure_nums_sum")
    private BigDecimal measureNumsSum; // 计量数量
    @TableField(value="conversion_unit")
    private String conversionUnit; // 重量转换系数单位
    @TableField(value="trans_scale_second")
    private BigDecimal transScaleSecond; // 第二次转换系数(主单位 - 吨)

    public BigDecimal getContractNumsSum() {
        return contractNumsSum;
    }

    public void setContractNumsSum(BigDecimal contractNumsSum) {
        this.contractNumsSum = contractNumsSum;
    }

    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public String getPassMuster() {
        return passMuster;
    }

    public void setPassMuster(String passMuster) {
        this.passMuster = passMuster;
    }

    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }

    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }

    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public BigDecimal getTheoreticalWeight() {
        return theoreticalWeight;
    }

    public void setTheoreticalWeight(BigDecimal theoreticalWeight) {
        this.theoreticalWeight = theoreticalWeight;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }

    public BigDecimal getMeasureNumsSum() {
        return measureNumsSum;
    }

    public void setMeasureNumsSum(BigDecimal measureNumsSum) {
        this.measureNumsSum = measureNumsSum;
    }

    public String getConversionUnit() {
        return conversionUnit;
    }

    public void setConversionUnit(String conversionUnit) {
        this.conversionUnit = conversionUnit;
    }

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    public void setDeliveryDetailId(Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getOrderDetailId() {
        return orderDetailId;
    }

    public void setOrderDetailId(Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getRmatDate() {
        return rmatDate;
    }

    public void setRmatDate(Date rmatDate) {
        this.rmatDate = rmatDate;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }

    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public BigDecimal getTransScaleSecond() {
        return transScaleSecond;
    }

    public void setTransScaleSecond(BigDecimal transScaleSecond) {
        this.transScaleSecond = transScaleSecond;
    }
}
